"use strict";
var _a, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGalileoMetricsWidgetPreferences = exports.GalileoMetricsWidgetPreferences = exports.galileoMetricsWidgetConfigurationSchema = void 0;
var inversify_1 = require("inversify");
var galileo_ide_metrics_dashboard_widget_widget_1 = require("./galileo-ide-metrics-dashboard-widget-widget");
var galileo_ide_metrics_dashboard_widget_contribution_1 = require("./galileo-ide-metrics-dashboard-widget-contribution");
var browser_1 = require("@theia/core/lib/browser");
require("../../src/browser/style/index.css");
exports.galileoMetricsWidgetConfigurationSchema = {
    $schema: "http://json-schema.org/draft-07/schema",
    $id: "http://example.com/example.json",
    type: "object",
    title: "The root schema",
    description: "The root schema comprises the entire JSON document.",
    default: {},
    examples: [
        (_a = {},
            _a["galileo.metrics.title" /* TITLE */] = "Metrics Dashboard",
            _a["galileo.metrics.metric_url" /* METRIC_URL */] = "http://127.0.0.1:8887/metrics.txt",
            _a["galileo.metrics.response_format" /* RESPONSE_FORMAT */] = "prometheus",
            _a["galileo.metrics.widgets" /* WIDGETS */] = [
                {
                    title: "By the numbers",
                    type: "single_value_container",
                    widgets: [
                        {
                            title: "Total Incoming Connections",
                            value_key: "ledger_blockq_init_count{}",
                            type: "single_value",
                            description_key: "help",
                        },
                        {
                            title: "Avg. Inclusion Distancefsfs fs afs fs fsafasfas fasfasfasfa sfsfs",
                            value_key: "avg_distance",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            unit: "Slot(s)",
                            fallback_value: "0",
                        },
                        {
                            title: "Recent Epoch Gains",
                            value_key: "ledger_blockq_sync_put_count{}",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            unit: "ETH",
                        },
                        {
                            title: "Correctly Voted Head Percent",
                            value_key: "ledger_initblocksdb_micros{}",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            unit: "%",
                        },
                        {
                            title: "Validating Keys",
                            value_key: "p2p/handle/eth/65/0x0a.std-dev|nested1|nested2",
                            type: "single_value",
                            key_separator: "|",
                            description: "Description to explain the metric.",
                        },
                    ],
                },
                {
                    title: "Chart Name",
                    metric_url: "http://127.0.0.1:8887/algo-metrics.json",
                    response_format: "json",
                    description: "Description for chart",
                    height: 500,
                    type: "bar_chart",
                    x_axis_label: "X Axis Label",
                    y_axis_label: "Y Axis Label",
                    fill_color: "blue",
                    config: [
                        {
                            key: "p2p/handle/eth/65/0x0a.95-percentile",
                            label: "95 Percentage",
                        },
                        {
                            key: "p2p/handle/eth/65/0x0a.99-percentile",
                            label: "99 Percentage",
                        },
                        {
                            key: "p2p/handle/eth/65/0x0a.75-percentile",
                            label: "75 Percentage",
                        },
                        {
                            key: "p2p/handle/eth/65/0x0a.50-percentile",
                            label: "50 Percentage",
                        },
                    ],
                },
                {
                    title: "Chart Name",
                    metric_url: "http://127.0.0.1:8887/algo-metrics.json",
                    response_format: "json",
                    description: "Description for chart",
                    height: 200,
                    fill_color: "purple",
                    type: "pie_chart",
                    config: [
                        {
                            key: "p2p/handle/eth/65/0x0a.95-percentile",
                            label: "First Value",
                        },
                        {
                            key: "p2p/handle/eth/65/0x0a.99-percentile",
                            label: "Best performing validator",
                        },
                    ],
                },
            ],
            _a),
    ],
    required: [
        "galileo.metrics.title",
        "galileo.metrics.metric_url",
        "galileo.metrics.response_format",
        "galileo.metrics.widgets",
    ],
    properties: (_b = {},
        _b["galileo.metrics.title" /* TITLE */] = {
            $id: "#/properties/galileo.metrics.title",
            type: "string",
            title: "The galileo.metrics.title schema",
            description: "The URL of the metrics, if this is provided in top level widget's value_key will be searched from this response (if no widget-specific metric_url provided).",
            default: "",
            examples: ["Metrics Dashboard"],
        },
        _b["galileo.metrics.metric_url" /* METRIC_URL */] = {
            $id: "#/properties/galileo.metrics.metric_url",
            type: "string",
            title: "The galileo.metrics.metric_url schema",
            description: "The URL of the metrics, if this is provided in top level widget's value_key will be searched from this response (if no widget-specific metric_url provided).",
            default: "",
            examples: ["http://127.0.0.1:8887/metrics.txt"],
        },
        _b["galileo.metrics.response_format" /* RESPONSE_FORMAT */] = {
            $id: "#/properties/galileo.metrics.response_format",
            type: "string",
            title: "The galileo.metrics.response_format schema",
            description: "Could be 'prometheus' or 'json'. According parser will be applied if 'prometheus'.",
            default: "",
            examples: ["prometheus"],
        },
        _b["galileo.metrics.widgets" /* WIDGETS */] = {
            $id: "#/properties/galileo.metrics.widgets",
            type: "array",
            title: "The galileo.metrics.widgets schema",
            description: "Widget array of the dashboard.",
            default: [],
            examples: [
                [
                    {
                        title: "By the numbers",
                        type: "single_value_container",
                        widgets: [
                            {
                                title: "Total Incoming Connections",
                                value_key: "ledger_blockq_init_count{}",
                                type: "single_value",
                                description_key: "help",
                            },
                            {
                                title: "Avg. Inclusion Distancefsfs fs afs fs fsafasfas fasfasfasfa sfsfs",
                                value_key: "avg_distance",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                unit: "Slot(s)",
                                fallback_value: "0",
                            },
                            {
                                title: "Recent Epoch Gains",
                                value_key: "ledger_blockq_sync_put_count{}",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                unit: "ETH",
                            },
                            {
                                title: "Correctly Voted Head Percent",
                                value_key: "ledger_initblocksdb_micros{}",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                unit: "%",
                            },
                            {
                                title: "Validating Keys",
                                value_key: "p2p/handle/eth/65/0x0a.std-dev|nested1|nested2",
                                type: "single_value",
                                key_separator: "|",
                                description: "Description to explain the metric.",
                            },
                        ],
                    },
                    {
                        title: "Chart Name",
                        metric_url: "http://127.0.0.1:8887/algo-metrics.json",
                        response_format: "json",
                        description: "Description for chart",
                        height: 500,
                        type: "bar_chart",
                        x_axis_label: "X Axis Label",
                        y_axis_label: "Y Axis Label",
                        fill_color: "blue",
                        config: [
                            {
                                key: "p2p/handle/eth/65/0x0a.95-percentile",
                                label: "95 Percentage",
                            },
                            {
                                key: "p2p/handle/eth/65/0x0a.99-percentile",
                                label: "99 Percentage",
                            },
                            {
                                key: "p2p/handle/eth/65/0x0a.75-percentile",
                                label: "75 Percentage",
                            },
                            {
                                key: "p2p/handle/eth/65/0x0a.50-percentile",
                                label: "50 Percentage",
                            },
                        ],
                    },
                ],
            ],
            additionalItems: true,
            items: {
                $id: "#/properties/galileo.metrics.widgets/items",
                anyOf: [
                    {
                        $id: "#/properties/galileo.metrics.widgets/items/anyOf/0",
                        type: "object",
                        title: "The first anyOf schema",
                        description: "An explanation about the purpose of this instance.",
                        default: {},
                        examples: [
                            {
                                title: "By the numbers",
                                type: "single_value_container",
                                widgets: [
                                    {
                                        title: "Total Incoming Connections",
                                        value_key: "ledger_blockq_init_count{}",
                                        type: "single_value",
                                        description_key: "help",
                                    },
                                    {
                                        title: "Avg. Inclusion Distancefsfs fs afs fs fsafasfas fasfasfasfa sfsfs",
                                        value_key: "avg_distance",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        unit: "Slot(s)",
                                        fallback_value: "0",
                                    },
                                    {
                                        title: "Recent Epoch Gains",
                                        value_key: "ledger_blockq_sync_put_count{}",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        unit: "ETH",
                                    },
                                    {
                                        title: "Correctly Voted Head Percent",
                                        value_key: "ledger_initblocksdb_micros{}",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        unit: "%",
                                    },
                                    {
                                        title: "Validating Keys",
                                        value_key: "p2p/handle/eth/65/0x0a.std-dev|nested1|nested2",
                                        type: "single_value",
                                        key_separator: "|",
                                        description: "Description to explain the metric.",
                                    },
                                ],
                            },
                        ],
                        required: ["title", "type", "widgets"],
                        properties: {
                            title: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/title",
                                type: "string",
                                title: "The title schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["By the numbers"],
                            },
                            type: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/type",
                                type: "string",
                                title: "The type schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["single_value_container"],
                            },
                            widgets: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets",
                                type: "array",
                                title: "The widgets schema",
                                description: "An explanation about the purpose of this instance.",
                                default: [],
                                examples: [
                                    [
                                        {
                                            title: "Total Incoming Connections",
                                            value_key: "ledger_blockq_init_count{}",
                                            type: "single_value",
                                            description_key: "help",
                                        },
                                        {
                                            title: "Avg. Inclusion Distancefsfs fs afs fs fsafasfas fasfasfasfa sfsfs",
                                            value_key: "avg_distance",
                                            type: "single_value",
                                            description: "Description to explain the metric.",
                                            unit: "Slot(s)",
                                            fallback_value: "0",
                                        },
                                    ],
                                ],
                                additionalItems: true,
                                items: {
                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items",
                                    anyOf: [
                                        {
                                            $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/0",
                                            type: "object",
                                            title: "The first anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Total Incoming Connections",
                                                    value_key: "ledger_blockq_init_count{}",
                                                    type: "single_value",
                                                    description_key: "help",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "description_key",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Total Incoming Connections"],
                                                },
                                                value_key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["ledger_blockq_init_count{}"],
                                                },
                                                type: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                description_key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/description_key",
                                                    type: "string",
                                                    title: "The description_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["help"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                        {
                                            $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1",
                                            type: "object",
                                            title: "The second anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Avg. Inclusion Distancefsfs fs afs fs fsafasfas fasfasfasfa sfsfs",
                                                    value_key: "avg_distance",
                                                    type: "single_value",
                                                    description: "Description to explain the metric.",
                                                    unit: "Slot(s)",
                                                    fallback_value: "0",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "description",
                                                "unit",
                                                "fallback_value",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: [
                                                        "Avg. Inclusion Distancefsfs fs afs fs fsafasfas fasfasfasfa sfsfs",
                                                    ],
                                                },
                                                value_key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["avg_distance"],
                                                },
                                                type: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                description: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/description",
                                                    type: "string",
                                                    title: "The description schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Description to explain the metric."],
                                                },
                                                unit: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/unit",
                                                    type: "string",
                                                    title: "The unit schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Slot(s)"],
                                                },
                                                fallback_value: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/fallback_value",
                                                    type: "string",
                                                    title: "The fallback_value schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["0"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                        {
                                            $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/2",
                                            type: "object",
                                            title: "The third anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Recent Epoch Gains",
                                                    value_key: "ledger_blockq_sync_put_count{}",
                                                    type: "single_value",
                                                    description: "Description to explain the metric.",
                                                    unit: "ETH",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "description",
                                                "unit",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Recent Epoch Gains"],
                                                },
                                                value_key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["ledger_blockq_sync_put_count{}"],
                                                },
                                                type: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                description: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/description",
                                                    type: "string",
                                                    title: "The description schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Description to explain the metric."],
                                                },
                                                unit: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/unit",
                                                    type: "string",
                                                    title: "The unit schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["ETH"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                        {
                                            $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/3",
                                            type: "object",
                                            title: "The fourth anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Validating Keys",
                                                    value_key: "p2p/handle/eth/65/0x0a.std-dev|nested1|nested2",
                                                    type: "single_value",
                                                    key_separator: "|",
                                                    description: "Description to explain the metric.",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "key_separator",
                                                "description",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/3/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Validating Keys"],
                                                },
                                                value_key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/3/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: [
                                                        "p2p/handle/eth/65/0x0a.std-dev|nested1|nested2",
                                                    ],
                                                },
                                                type: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/3/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                key_separator: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/3/properties/key_separator",
                                                    type: "string",
                                                    title: "The key_separator schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["|"],
                                                },
                                                description: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/0/properties/widgets/items/anyOf/3/properties/description",
                                                    type: "string",
                                                    title: "The description schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Description to explain the metric."],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                    ],
                                },
                            },
                        },
                        additionalProperties: true,
                    },
                    {
                        $id: "#/properties/galileo.metrics.widgets/items/anyOf/1",
                        type: "object",
                        title: "The second anyOf schema",
                        description: "An explanation about the purpose of this instance.",
                        default: {},
                        examples: [
                            {
                                title: "Chart Name",
                                metric_url: "http://127.0.0.1:8887/algo-metrics.json",
                                response_format: "json",
                                description: "Description for chart",
                                height: 500,
                                type: "bar_chart",
                                x_axis_label: "X Axis Label",
                                y_axis_label: "Y Axis Label",
                                fill_color: "blue",
                                config: [
                                    {
                                        key: "p2p/handle/eth/65/0x0a.95-percentile",
                                        label: "95 Percentage",
                                    },
                                    {
                                        key: "p2p/handle/eth/65/0x0a.99-percentile",
                                        label: "99 Percentage",
                                    },
                                    {
                                        key: "p2p/handle/eth/65/0x0a.75-percentile",
                                        label: "75 Percentage",
                                    },
                                    {
                                        key: "p2p/handle/eth/65/0x0a.50-percentile",
                                        label: "50 Percentage",
                                    },
                                ],
                            },
                        ],
                        required: [
                            "title",
                            "metric_url",
                            "response_format",
                            "description",
                            "height",
                            "type",
                            "x_axis_label",
                            "y_axis_label",
                            "fill_color",
                            "config",
                        ],
                        properties: {
                            title: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/title",
                                type: "string",
                                title: "The title schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Chart Name"],
                            },
                            metric_url: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/metric_url",
                                type: "string",
                                title: "The metric_url schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["http://127.0.0.1:8887/algo-metrics.json"],
                            },
                            response_format: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/response_format",
                                type: "string",
                                title: "The response_format schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["json"],
                            },
                            description: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/description",
                                type: "string",
                                title: "The description schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Description for chart"],
                            },
                            height: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/height",
                                type: "integer",
                                title: "The height schema",
                                description: "An explanation about the purpose of this instance.",
                                default: 0,
                                examples: [500],
                            },
                            type: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/type",
                                type: "string",
                                title: "The type schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["bar_chart"],
                            },
                            x_axis_label: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/x_axis_label",
                                type: "string",
                                title: "The x_axis_label schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["X Axis Label"],
                            },
                            y_axis_label: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/y_axis_label",
                                type: "string",
                                title: "The y_axis_label schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Y Axis Label"],
                            },
                            fill_color: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/fill_color",
                                type: "string",
                                title: "The fill_color schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["blue"],
                            },
                            config: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/config",
                                type: "array",
                                title: "The config schema",
                                description: "An explanation about the purpose of this instance.",
                                default: [],
                                examples: [
                                    [
                                        {
                                            key: "p2p/handle/eth/65/0x0a.95-percentile",
                                            label: "95 Percentage",
                                        },
                                        {
                                            key: "p2p/handle/eth/65/0x0a.99-percentile",
                                            label: "99 Percentage",
                                        },
                                    ],
                                ],
                                additionalItems: true,
                                items: {
                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/config/items",
                                    anyOf: [
                                        {
                                            $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/config/items/anyOf/0",
                                            type: "object",
                                            title: "The first anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    key: "p2p/handle/eth/65/0x0a.95-percentile",
                                                    label: "95 Percentage",
                                                },
                                            ],
                                            required: ["key", "label"],
                                            properties: {
                                                key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/config/items/anyOf/0/properties/key",
                                                    type: "string",
                                                    title: "The key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["p2p/handle/eth/65/0x0a.95-percentile"],
                                                },
                                                label: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/1/properties/config/items/anyOf/0/properties/label",
                                                    type: "string",
                                                    title: "The label schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["95 Percentage"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                    ],
                                },
                            },
                        },
                        additionalProperties: true,
                    },
                    {
                        $id: "#/properties/galileo.metrics.widgets/items/anyOf/2",
                        type: "object",
                        title: "The third anyOf schema",
                        description: "An explanation about the purpose of this instance.",
                        default: {},
                        examples: [
                            {
                                title: "Chart Name",
                                metric_url: "http://127.0.0.1:8887/algo-metrics.json",
                                response_format: "json",
                                description: "Description for chart",
                                height: 200,
                                fill_color: "purple",
                                type: "pie_chart",
                                config: [
                                    {
                                        key: "p2p/handle/eth/65/0x0a.95-percentile",
                                        label: "First Value",
                                    },
                                    {
                                        key: "p2p/handle/eth/65/0x0a.99-percentile",
                                        label: "Best performing validator",
                                    },
                                ],
                            },
                        ],
                        required: [
                            "title",
                            "metric_url",
                            "response_format",
                            "description",
                            "height",
                            "fill_color",
                            "type",
                            "config",
                        ],
                        properties: {
                            title: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/title",
                                type: "string",
                                title: "The title schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Chart Name"],
                            },
                            metric_url: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/metric_url",
                                type: "string",
                                title: "The metric_url schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["http://127.0.0.1:8887/algo-metrics.json"],
                            },
                            response_format: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/response_format",
                                type: "string",
                                title: "The response_format schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["json"],
                            },
                            description: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/description",
                                type: "string",
                                title: "The description schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Description for chart"],
                            },
                            height: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/height",
                                type: "integer",
                                title: "The height schema",
                                description: "An explanation about the purpose of this instance.",
                                default: 0,
                                examples: [200],
                            },
                            fill_color: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/fill_color",
                                type: "string",
                                title: "The fill_color schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["purple"],
                            },
                            type: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/type",
                                type: "string",
                                title: "The type schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["pie_chart"],
                            },
                            config: {
                                $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/config",
                                type: "array",
                                title: "The config schema",
                                description: "An explanation about the purpose of this instance.",
                                default: [],
                                examples: [
                                    [
                                        {
                                            key: "p2p/handle/eth/65/0x0a.95-percentile",
                                            label: "First Value",
                                        },
                                        {
                                            key: "p2p/handle/eth/65/0x0a.99-percentile",
                                            label: "Best performing validator",
                                        },
                                    ],
                                ],
                                additionalItems: true,
                                items: {
                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/config/items",
                                    anyOf: [
                                        {
                                            $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/config/items/anyOf/0",
                                            type: "object",
                                            title: "The first anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    key: "p2p/handle/eth/65/0x0a.95-percentile",
                                                    label: "First Value",
                                                },
                                            ],
                                            required: ["key", "label"],
                                            properties: {
                                                key: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/config/items/anyOf/0/properties/key",
                                                    type: "string",
                                                    title: "The key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["p2p/handle/eth/65/0x0a.95-percentile"],
                                                },
                                                label: {
                                                    $id: "#/properties/galileo.metrics.widgets/items/anyOf/2/properties/config/items/anyOf/0/properties/label",
                                                    type: "string",
                                                    title: "The label schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["First Value"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                    ],
                                },
                            },
                        },
                        additionalProperties: true,
                    },
                ],
            },
        },
        _b),
    additionalProperties: true,
};
exports.GalileoMetricsWidgetPreferences = Symbol("GalileoMetricsWidgetPreferences");
function createGalileoMetricsWidgetPreferences(preferences) {
    return browser_1.createPreferenceProxy(preferences, exports.galileoMetricsWidgetConfigurationSchema);
}
exports.createGalileoMetricsWidgetPreferences = createGalileoMetricsWidgetPreferences;
exports.default = new inversify_1.ContainerModule(function (bind) {
    browser_1.bindViewContribution(bind, galileo_ide_metrics_dashboard_widget_contribution_1.GalileoIdeMetricsDashboardWidgetContribution);
    bind(browser_1.FrontendApplicationContribution).toService(galileo_ide_metrics_dashboard_widget_contribution_1.GalileoIdeMetricsDashboardWidgetContribution);
    bind(galileo_ide_metrics_dashboard_widget_widget_1.GalileoIdeMetricsDashboardWidgetWidget).toSelf();
    bind(browser_1.WidgetFactory)
        .toDynamicValue(function (ctx) { return ({
        id: galileo_ide_metrics_dashboard_widget_widget_1.GalileoIdeMetricsDashboardWidgetWidget.ID,
        createWidget: function () {
            return ctx.container.get(galileo_ide_metrics_dashboard_widget_widget_1.GalileoIdeMetricsDashboardWidgetWidget);
        },
    }); })
        .inSingletonScope();
    bind(exports.GalileoMetricsWidgetPreferences).toDynamicValue(function (ctx) {
        var preferences = ctx.container.get(browser_1.PreferenceService);
        return createGalileoMetricsWidgetPreferences(preferences);
    });
    bind(browser_1.PreferenceContribution).toConstantValue({
        schema: exports.galileoMetricsWidgetConfigurationSchema,
    });
});
//# sourceMappingURL=galileo-ide-metrics-dashboard-widget-frontend-module.js.map