import * as React from "react";
import { BarChart, Bar, XAxis, YAxis, CartesianGrid, Tooltip } from "recharts";
import { useMetricWidgetContext } from "../MetricWidgetContext";
import { useEffect, useState } from "@theia/core/shared/react";
import { IMetricWidget } from "../MetricWidget.interface";
import ChartContainer from "../ChartContainer";

interface IBarChartWidgetProps {
  widget: IMetricWidget;
}
const BarChartWidget = (props: IBarChartWidgetProps) => {
  const { widget } = props;
  const {
    title,
    description,
    height = 500,
    config,
    response_format,
    metric_url,
    fill_color = "blue",
  } = widget;
  const { getValueByKey, globalResponse, responseDict, globalResponseFormat } =
    useMetricWidgetContext();
  const [parsedData, setParsedData] = useState();
  useEffect(() => {
    parseData();
  }, [
    JSON.stringify(globalResponse),
    JSON.stringify(responseDict),
    globalResponseFormat,
  ]);

  const parseData = () => {
    let parsedDataArr: any = [];
    config?.forEach((item) => {
      // const keys = item.keys?.map((itemKey: IBarChartKeyConfig) => {
      //   return {
      //     [itemKey.label]: getValueByKey({
      //       key: itemKey.key,
      //       responseFormat: response_format,
      //       metricUrl: metric_url,
      //     }),
      //   };
      // });
      parsedDataArr.push({
        name: item.label,
        value: getValueByKey({
          key: item.key,
          responseFormat: response_format,
          metricUrl: metric_url,
        }),
      });
    });
    setParsedData(parsedDataArr);
  };

  return (
    <ChartContainer height={height} title={title} description={description}>
      <BarChart
        data={parsedData}
        margin={{
          top: 0,
          right: 24,
          left: 0,
          bottom: 24,
        }}
      >
        <CartesianGrid strokeDasharray="3 3" />
        <XAxis
          dataKey="name"
          label={{
            value: widget.x_axis_label,
            position: "bottom",
          }}
        />
        <YAxis
          label={{
            value: widget.y_axis_label,
            angle: -90,
            offset: 12,
            position: "insideLeft",
          }}
        />
        <Tooltip
          formatter={(value: any) => {
            return [value, ""];
          }}
          separator=""
        />
        {/* <Legend
          layout="vertical"
          verticalAlign="top"
          align="right"
          margin={{
            top: -48,
            right: 24,
            left: 0,
            bottom: 0,
          }}
        /> */}
        {/* {config?.map((item: IBarChartConfig) => {
          return item.keys?.map((itemKey: IBarChartKeyConfig) => (
            
          ));
        })} */}
        <Bar
          isAnimationActive={false}
          dataKey="value"
          fill={`var(--theia-charts-${fill_color})`}
        />
      </BarChart>
    </ChartContainer>
  );
};

export default BarChartWidget;
