import * as React from "react";
import { createUseStyles } from "react-jss";
import { ResponsiveContainer } from "recharts";

const useStyles = createUseStyles({
  outerContainer: {
    height: "100%",
    width: "100%",
    backgroundColor: "var(--theia-button-background)",
    color: "var(--theia-button-foreground)",
    "&:hover": {
      backgroundColor: "var(--theia-button-hoverBackground)",
    },
    borderRadius: "6px",
    marginTop: 36,
  },
  subTitle: {
    color: "var(--theia-descriptionForeground)",
    fontSize: 18,
    margin: "8px 0 24px 0",
  },
  label: {
    margin: 0,
    fontWeight: 600,
    color: "var(--theia-descriptionForeground)",
    fontSize: 24,
  },
  headerContainer: {
    padding: 24,
  },
});
interface IChartContainerProps {
  children: React.ReactNode;
  title: string;
  description?: string;
  height: number;
}
const ChartContainer = (props: IChartContainerProps) => {
  const { children, title, description, height = 500 } = props;

  const classes = useStyles();

  return (
    <div className={classes.outerContainer}>
      <div className={classes.headerContainer}>
        <p className={classes.label}>{title}</p>
        <p className={classes.subTitle}>{description}</p>
      </div>
      <ResponsiveContainer height={height} width={"100%"}>
        {children}
      </ResponsiveContainer>
    </div>
  );
};

export default ChartContainer;
