import * as React from "react";
import { PieChart, Pie, Tooltip } from "recharts";
import { useMetricWidgetContext } from "../MetricWidgetContext";
import { useEffect, useState } from "@theia/core/shared/react";
import { IMetricWidget } from "../MetricWidget.interface";
import ChartContainer from "../ChartContainer";

interface IPieChartWidgetProps {
  widget: IMetricWidget;
}
interface IPieChartData {
  name: string;
  value: number;
}
const PieChartWidget = (props: IPieChartWidgetProps) => {
  const { widget } = props;
  const {
    title,
    description,
    height = 500,
    config,
    response_format,
    metric_url,
    fill_color = "blue",
  } = widget;
  const { getValueByKey, globalResponse, responseDict, globalResponseFormat } =
    useMetricWidgetContext();
  const [parsedData, setParsedData] = useState<IPieChartData[]>([]);
  useEffect(() => {
    parseData();
  }, [
    JSON.stringify(globalResponse),
    JSON.stringify(responseDict),
    globalResponseFormat,
  ]);

  const parseData = () => {
    let parsedDataArr: any = [];
    config?.forEach((item) => {
      parsedDataArr.push({
        name: item.label,
        value: getValueByKey({
          key: item.key,
          responseFormat: response_format,
          metricUrl: metric_url,
        }),
      });
    });
    setParsedData(parsedDataArr);
  };

  return (
    <ChartContainer
      height={height + 96}
      title={title}
      description={description}
    >
      <PieChart height={height + 96}>
        <Pie
          data={parsedData}
          dataKey="value"
          nameKey="name"
          label
          labelLine
          isAnimationActive={false}
          fill={`var(--theia-charts-${fill_color})`}
        ></Pie>
        <Tooltip />
      </PieChart>
    </ChartContainer>
  );
};

export default PieChartWidget;
